purge_bad_keywords — MSUMastro toolbox 0.1 documentation

# purge_bad_keywords

`msumastro.header_processing.patchers.` `purge_bad_keywords`(header, history=False, force=False, file_name=None)

  Remove keywords from FITS header that may be incorrect

  Parameters: | header : astropy.io.fits.Header Header from which the bad keywords (as defined by the software that recorded the image) should be purged. history : bool If True write detailed history for each keyword removed. force : bool If True, force keywords to be purged even if the FITS header indicates it has already been purged. file_name : str, optional Name of file containing the header; if provided it is used to generate more informative log messages.